@@ -431,8 +431,11 @@ char* userrec::MakeHostIP()
 
 void userrec::CloseSocket()
 {
-	shutdown(this->fd,2);
-	close(this->fd);
+	if (this->fd > -1)
+	{
+		shutdown(this->fd,2);
+		close(this->fd);
+	}
 }
 
 char* userrec::GetFullHost()
@@ -1071,7 +1074,7 @@ void userrec::FullConnect()
 		{
 			char reason[MAXBUF];
 			if (*ServerInstance->Config->MoronBanner)
-				this->WriteServ("NOTICE %s :*** %s", this, ServerInstance->Config->MoronBanner);
+				this->WriteServ("NOTICE %s :*** %s", this->nick, ServerInstance->Config->MoronBanner);
 			snprintf(reason,MAXBUF,"K-Lined: %s",n->reason);
 			userrec::QuitUser(ServerInstance, this, reason);
 			return;
@@ -1080,9 +1083,9 @@ void userrec::FullConnect()
 
 	this->WriteServ("NOTICE Auth :Welcome to \002%s\002!",ServerInstance->Config->Network);
 	this->WriteServ("001 %s :Welcome to the %s IRC Network %s!%s@%s",this->nick, ServerInstance->Config->Network, this->nick, this->ident, this->host);
-	this->WriteServ("002 %s :Your host is %s, running version %s",this->nick,ServerInstance->Config->ServerName,VERSION);
+	this->WriteServ("002 %s :Your host is %s, running version InspIRCd-1.1",this->nick,ServerInstance->Config->ServerName);
 	this->WriteServ("003 %s :This server was created %s %s", this->nick, __TIME__, __DATE__);
-	this->WriteServ("004 %s %s %s %s %s %s", this->nick, ServerInstance->Config->ServerName, VERSION, ServerInstance->Modes->UserModeList().c_str(), ServerInstance->Modes->ChannelModeList().c_str(), ServerInstance->Modes->ParaModeList().c_str());
+	this->WriteServ("004 %s %s InspIRCd-1.1 %s %s %s", this->nick, ServerInstance->Config->ServerName, ServerInstance->Modes->UserModeList().c_str(), ServerInstance->Modes->ChannelModeList().c_str(), ServerInstance->Modes->ParaModeList().c_str());
 
 	ServerInstance->Config->Send005(this);
 
@@ -1615,9 +1618,6 @@ void userrec::WriteCommonExcept(const std::string &text)
 
 void userrec::WriteWallOps(const std::string &text)
 {
-	if (!IS_OPER(this) && IS_LOCAL(this))
-		return;
-
 	std::string wallop("WALLOPS :");
 	wallop.append(text);
 
